"use strict";
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.showHelp = exports.getOptions = void 0;
const command_line_args_1 = __importDefault(require("command-line-args"));
const command_line_usage_1 = __importDefault(require("command-line-usage"));
const path_1 = __importDefault(require("path"));
const optionList = [
    {
        name: 'payload',
        alias: 'p',
        type: String,
        description: 'Path to payload root folder, required if not current folder',
        group: 'basic',
    },
    {
        name: 'config',
        alias: 'c',
        type: String,
        description: 'Path to payload config',
        group: 'basic',
    },
    {
        name: 'output',
        alias: 'o',
        type: String,
        description: 'Location to store the payload docs, default <payload-root-folder>/doc/spec.json',
        group: 'basic',
    },
    {
        name: 'help',
        type: Boolean,
        description: 'shows this help screen',
    },
    {
        name: 'disableAllAccessAnalysis',
        type: Boolean,
        description: 'Disable all endpoint access analysis',
        group: 'options',
    },
    {
        name: 'disableAccessAnalysis',
        multiple: true,
        type: String,
        description: 'Disable endpoint analysis for the collections with the given slugs',
        group: 'options',
    },
    {
        name: 'excludeAuthPaths',
        type: Boolean,
        description: 'Exclude auth paths from the openapi document',
        group: 'options',
    },
    {
        name: 'excludeAuthCollection',
        type: Boolean,
        description: 'Exclude paths of auth collections from the openapi document',
        group: 'options',
    },
    {
        name: 'includePasswordRecovery',
        type: Boolean,
        description: 'Include password recovery paths in the openapi documents',
        group: 'options',
    },
    {
        name: 'includePreferences',
        type: Boolean,
        description: 'Include preference paths in the openapi documents',
        group: 'options',
    },
    {
        name: 'excludeCustom',
        type: Boolean,
        description: 'Exclude custom paths from the openapi documents',
        group: 'options',
    },
];
const sections = [
    {
        header: 'create-payload-api-docs',
        content: `Run 'npx create-payload-api-docs' from the root folder of your payload repository to generate the openapi docs.

    For more options, see the options list below.`,
    },
    {
        header: 'Basic configuration',
        optionList,
        group: ['basic'],
    },
    {
        header: 'Generator options\n\nSee payload-openapi docs for more details: https://www.npmjs.com/package/payload-openapi',
        optionList,
        group: ['options'],
    },
];
const toAbsolutePath = (value) => {
    if (!value || path_1.default.isAbsolute(value)) {
        return value;
    }
    return path_1.default.join(process.cwd(), value);
};
const toOpenapiOptions = (args) => ({
    disableAccessAnalysis: args.disableAllAccessAnalysis || args.disableAccessAnalysis,
    exclude: {
        authPaths: args.excludeAuthPaths,
        authCollection: args.excludeAuthCollection,
        passwordRecovery: !args.includePasswordRecovery,
        preferences: !args.includePreferences,
        custom: args.excludeCustom,
    },
});
const getOptions = () => {
    const args = (0, command_line_args_1.default)(
    // eslint-disable-next-line @typescript-eslint/no-unused-vars
    optionList.map((_a) => {
        var { description, group } = _a, rest = __rest(_a, ["description", "group"]);
        return rest;
    }), { caseInsensitive: true });
    return {
        help: args.help,
        payloadPath: toAbsolutePath(args.payload),
        configPath: toAbsolutePath(args.config),
        outputPath: toAbsolutePath(args.output),
        generatorOptions: toOpenapiOptions(args),
    };
};
exports.getOptions = getOptions;
const showHelp = () => {
    const usage = (0, command_line_usage_1.default)(sections);
    console.log(usage);
};
exports.showHelp = showHelp;
